==> openshift-model-config-6.6.2-sources.jar: io/fabric8/openshift/api/model/config/v1/HTPasswdIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface HTPasswdIdentityProviderFluent<A extends HTPasswdIdentityProviderFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildFileData instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getFileData();
  public SecretNameReference buildFileData();
  public A withFileData(SecretNameReference fileData);
  public Boolean hasFileData();
  public A withNewFileData(String name);
  public HTPasswdIdentityProviderFluent.FileDataNested<A> withNewFileData();
  public HTPasswdIdentityProviderFluent.FileDataNested<A> withNewFileDataLike(SecretNameReference item);
  public HTPasswdIdentityProviderFluent.FileDataNested<A> editFileData();
  public HTPasswdIdentityProviderFluent.FileDataNested<A> editOrNewFileData();
  public HTPasswdIdentityProviderFluent.FileDataNested<A> editOrNewFileDataLike(SecretNameReference item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface FileDataNested<N> extends Nested<N>,SecretNameReferenceFluent<HTPasswdIdentityProviderFluent.FileDataNested<N>>{
    public N and();
    public N endFileData();
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/HTPasswdIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTPasswdIdentityProviderFluent<A extends HTPasswdIdentityProviderFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildFileData instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getFileData();
  public SecretNameReference buildFileData();
  public A withFileData(SecretNameReference fileData);
  public Boolean hasFileData();
  public A withNewFileData(String name);
  public HTPasswdIdentityProviderFluent.FileDataNested<A> withNewFileData();
  public HTPasswdIdentityProviderFluent.FileDataNested<A> withNewFileDataLike(SecretNameReference item);
  public HTPasswdIdentityProviderFluent.FileDataNested<A> editFileData();
  public HTPasswdIdentityProviderFluent.FileDataNested<A> editOrNewFileData();
  public HTPasswdIdentityProviderFluent.FileDataNested<A> editOrNewFileDataLike(SecretNameReference item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface FileDataNested<N> extends Nested<N>,SecretNameReferenceFluent<HTPasswdIdentityProviderFluent.FileDataNested<N>>{
    public N and();
    public N endFileData();
    
  }
  
}
